#ifndef GLOBAL_H
#define GLOBAL_H

// Main
#define DEFAULT_StartingLocation "/home/user/MyDocs"
#define DEFAULT_StartInBookmarks false
#define DEFAULT_Orientation "automatic"
#define DEFAULT_RunAsRoot false

// Browser
#define DEFAULT_GridView false
#define DEFAULT_ShowHidden false
#define DEFAULT_ShowThumbnails false
#define DEFAULT_HideLocationBar false
#define DEFAULT_FirstDetail FileSystemModel::Size
#define DEFAULT_SecondDetail FileSystemModel::Date
#define DEFAULT_Sorting QDir::Name

// Clipboard
#define DEFAULT_SelectNewItems true
#define DEFAULT_AddingClearsSelection true
#define DEFAULT_QueryingClearsSelection true
#define DEFAULT_SaveOnExit false

// Operations
#define DEFAULT_ArchiveSize 10
#define DEFAULT_ActiveLimiter false
#define DEFAULT_MaxActive 1

#endif // GLOBAL_H
